==> nats.c_3.4.1.orig.tar.gz: nats.c-3.4.1/doc/html/group__opts_group.js <==
var group__opts_group =
[
    [ "natsOptions_Create", "group__opts_group.html#ga61d4a0cf2fbf7d13cc910e5a00c575be", null ],
    [ "natsOptions_SetURL", "group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5", null ],
    [ "natsOptions_SetServers", "group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf", null ],
    [ "natsOptions_SetUserInfo", "group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e", null ],
    [ "natsOptions_SetToken", "group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193", null ],
    [ "natsOptions_SetTokenHandler", "group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426", null ],
    [ "natsOptions_SetNoRandomize", "group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413", null ],
    [ "natsOptions_SetTimeout", "group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9", null ],
    [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
    [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
    [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
    [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
    [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
    [ "natsOptions_SetCertificatesChain", "group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c", null ],
    [ "natsOptions_SetCiphers", "group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c", null ],
    [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
    [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
    [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
    [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
    [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
    [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
    [ "natsOptions_SetMaxPingsOut", "group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b", null ],
    [ "natsOptions_SetIOBufSize", "group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3", null ],
    [ "natsOptions_SetAllowReconnect", "group__opts_group.html#ga3d1d3cb2f2a0e23d27dd60e96d1cc91b", null ],
    [ "natsOptions_SetMaxReconnect", "group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0", null ],
    [ "natsOptions_SetReconnectWait", "group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807", null ],
    [ "natsOptions_SetReconnectJitter", "group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2", null ],
    [ "natsOptions_SetCustomReconnectDelay", "group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d", null ],
    [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
    [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
    [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
    [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
    [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
    [ "natsOptions_SetReconnectedCB", "group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980", null ],
    [ "natsOptions_SetDiscoveredServersCB", "group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65", null ],
    [ "natsOptions_SetIgnoreDiscoveredServers", "group__opts_group.html#ga7e4172084520708b8c9f28e73174461c", null ],
    [ "natsOptions_SetLameDuckModeCB", "group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc", null ],
    [ "natsOptions_SetEventLoop", "group__opts_group.html#gab09491bad908dedcb323c780280733ff", null ],
    [ "natsOptions_UseGlobalMessageDelivery", "group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c", null ],
    [ "natsOptions_IPResolutionOrder", "group__opts_group.html#ga7ca713c7532eff4d41a492e95b8822cf", null ],
    [ "natsOptions_SetSendAsap", "group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca", null ],
    [ "natsOptions_UseOldRequestStyle", "group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6", null ],
    [ "natsOptions_SetFailRequestsOnDisconnect", "group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79", null ],
    [ "natsOptions_SetNoEcho", "group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3", null ],
    [ "natsOptions_SetRetryOnFailedConnect", "group__opts_group.html#ga20946800d024b7089e73d63454d1c19f", null ],
    [ "natsOptions_SetUserCredentialsCallbacks", "group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515", null ],
    [ "natsOptions_SetUserCredentialsFromFiles", "group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e", null ],
    [ "natsOptions_SetNKey", "group__opts_group.html#ga0290eac4665569c850468d9f00e246a0", null ],
    [ "natsOptions_SetNKeyFromSeed", "group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e", null ],
    [ "natsOptions_SetWriteDeadline", "group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218", null ],
    [ "natsOptions_DisableNoResponders", "group__opts_group.html#ga192465163abb87ad48a843b45cdf9984", null ],
    [ "natsOptions_SetCustomInboxPrefix", "group__opts_group.html#gac5173473a731a4a36d15346fedddf91f", null ],
    [ "natsOptions_Destroy", "group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9", null ]
];

==> nats.c_3.7.0.orig.tar.gz: nats.c-3.7.0/doc/html/group__opts_group.js <==
var group__opts_group =
[
    [ "natsOptions_Create", "group__opts_group.html#ga61d4a0cf2fbf7d13cc910e5a00c575be", null ],
    [ "natsOptions_SetURL", "group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5", null ],
    [ "natsOptions_SetServers", "group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf", null ],
    [ "natsOptions_SetUserInfo", "group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e", null ],
    [ "natsOptions_SetToken", "group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193", null ],
    [ "natsOptions_SetTokenHandler", "group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426", null ],
    [ "natsOptions_SetNoRandomize", "group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413", null ],
    [ "natsOptions_SetTimeout", "group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9", null ],
    [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
    [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
    [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
    [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
    [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
    [ "natsOptions_SetCertificatesChain", "group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c", null ],
    [ "natsOptions_SetCiphers", "group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c", null ],
    [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
    [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
    [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
    [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
    [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
    [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
    [ "natsOptions_SetMaxPingsOut", "group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b", null ],
    [ "natsOptions_SetIOBufSize", "group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3", null ],
    [ "natsOptions_SetAllowReconnect", "group__opts_group.html#ga3d1d3cb2f2a0e23d27dd60e96d1cc91b", null ],
    [ "natsOptions_SetMaxReconnect", "group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0", null ],
    [ "natsOptions_SetReconnectWait", "group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807", null ],
    [ "natsOptions_SetReconnectJitter", "group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2", null ],
    [ "natsOptions_SetCustomReconnectDelay", "group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d", null ],
    [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
    [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
    [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
    [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
    [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
    [ "natsOptions_SetReconnectedCB", "group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980", null ],
    [ "natsOptions_SetDiscoveredServersCB", "group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65", null ],
    [ "natsOptions_SetIgnoreDiscoveredServers", "group__opts_group.html#ga7e4172084520708b8c9f28e73174461c", null ],
    [ "natsOptions_SetLameDuckModeCB", "group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc", null ],
    [ "natsOptions_SetEventLoop", "group__opts_group.html#gab09491bad908dedcb323c780280733ff", null ],
    [ "natsOptions_UseGlobalMessageDelivery", "group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c", null ],
    [ "natsOptions_IPResolutionOrder", "group__opts_group.html#ga7ca713c7532eff4d41a492e95b8822cf", null ],
    [ "natsOptions_SetSendAsap", "group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca", null ],
    [ "natsOptions_UseOldRequestStyle", "group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6", null ],
    [ "natsOptions_SetFailRequestsOnDisconnect", "group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79", null ],
    [ "natsOptions_SetNoEcho", "group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3", null ],
    [ "natsOptions_SetRetryOnFailedConnect", "group__opts_group.html#ga20946800d024b7089e73d63454d1c19f", null ],
    [ "natsOptions_SetUserCredentialsCallbacks", "group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515", null ],
    [ "natsOptions_SetUserCredentialsFromFiles", "group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e", null ],
    [ "natsOptions_SetUserCredentialsFromMemory", "group__opts_group.html#ga5d3d4d1269dd289f93c56b8a1ddccd43", null ],
    [ "natsOptions_SetNKey", "group__opts_group.html#ga0290eac4665569c850468d9f00e246a0", null ],
    [ "natsOptions_SetNKeyFromSeed", "group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e", null ],
    [ "natsOptions_SetWriteDeadline", "group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218", null ],
    [ "natsOptions_DisableNoResponders", "group__opts_group.html#ga192465163abb87ad48a843b45cdf9984", null ],
    [ "natsOptions_SetCustomInboxPrefix", "group__opts_group.html#gac5173473a731a4a36d15346fedddf91f", null ],
    [ "natsOptions_SetMessageBufferPadding", "group__opts_group.html#ga5acd292cdaeb63d3d7bd9bbc05513c8f", null ],
    [ "natsOptions_Destroy", "group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9", null ]
];
